import cookieParser from "cookie-parser";
import "dotenv/config";
import express from "express";
import initializeDatabase from "./db";
import createInitialEmployeeIfNotExists from "./db/createInitialEmployee";
import accountsRouter from "./routes/accounts.routes";
import authRouter from "./routes/auth.routes";
import boatsRouter from "./routes/boat.routes";
import userRouter from "./routes/user.routes";
import boatTypeRouter from "./routes/boatType.routes";
import entryRouter from "./routes/createLogEntry.routes";
import sportRouter from "./routes/sport.routes";

let init = async () => {
  //DB
  const sequelize = await initializeDatabase();
  await createInitialEmployeeIfNotExists();
  // server
  const app = express();
  app.use(express.json());
  app.use(cookieParser());
  const port = process.env.PORT || 4000;
  app.listen(port, () => {});
  app.use("/", authRouter);
  app.use("/", accountsRouter);
  app.use("/", boatsRouter);
  app.use("/", userRouter);
  app.use("/", boatTypeRouter);
  app.use("/", entryRouter);
  app.use("/", sportRouter);
};

init().then(() => {});
